=== modified file '__init__.py'
--- __init__.py	2010-09-20 03:17:41 +0000
+++ __init__.py	2010-09-28 02:28:58 +0000
@@ -16,14 +16,20 @@
 
 __doc__ = """Merge hook for GNU-format ChangeLog files
 
-To enable this plugin, add a section to your branch.conf or location.conf
+To enable this plugin, add a section to your location.conf
 like::
 
     [/home/user/proj]
     changelog_merge_files = ChangeLog
 
-The changelog_merge_files config option takes a list of file paths, separated
-by commas.
+Or add an entry to your branch.conf like::
+
+    changelog_merge_files = ChangeLog
+
+The changelog_merge_files config option takes a list of file names (not paths),
+separated by commas.  (This is unlike the news_merge plugin, which matches
+paths.)  e.g. the above config examples would match both
+``src/foolib/ChangeLog`` and ``docs/ChangeLog``.
 
 The algorithm this implements is very simple: it emits all the entries in OTHER
 that are new compared to the common base version, followed by all the entries

=== modified file 'changelog_merge.py'
--- changelog_merge.py	2010-09-20 03:17:41 +0000
+++ changelog_merge.py	2010-09-28 02:28:58 +0000
@@ -53,6 +53,19 @@
 
     name_prefix = "changelog"
 
+    def get_filepath(self, params, tree):
+        """Calculate the path to the file in a tree.
+
+        This is overridden to return just the basename, rather than full path,
+        so that e.g. if the config says ``changelog_merge_files = ChangeLog``,
+        then all ChangeLog files in the tree will match (not just one in the
+        root of the tree).
+        
+        :param params: A MergeHookParams describing the file to merge
+        :param tree: a Tree, e.g. self.merger.this_tree.
+        """
+        return tree.inventory[params.file_id].name
+
     def merge_text(self, params):
         """Float new changelog sections from other to the top of the changelog.
 

